==> lxqt-panel-1.0.0.tar.xz: lxqt-panel-1.0.0/plugin-taskbar/translations/taskbar_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../lxqttaskbar.cpp" line="681"/>
        <source>Activate task %1</source>
        <translation>Activar la tarea %1</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="677"/>
        <source>Application</source>
        <translation>Aplicación</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="711"/>
        <source>To &amp;Desktop</source>
        <translation>Al &amp;escritorio</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="713"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Todos los escritorios</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="721"/>
        <source>Desktop &amp;%1</source>
        <translation>Escritorio &amp;%1</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="728"/>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Al escritorio actual</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="737"/>
        <source>Move To &amp;Next Monitor</source>
        <translation type="unfinished">Ir al siguie&amp;nte monitor</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="740"/>
        <source>Move To &amp;Previous Monitor</source>
        <translation type="unfinished">Ir al monitor anterior</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="744"/>
        <source>&amp;Move</source>
        <translation>&amp;Mover</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="747"/>
        <source>Resi&amp;ze</source>
        <translation>Cambiar el tamaño</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="754"/>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximizar</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="761"/>
        <source>Maximize vertically</source>
        <translation>Maximizar verticalmente</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="766"/>
        <source>Maximize horizontally</source>
        <translation>Maximizar horizontalmente</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="772"/>
        <source>&amp;Restore</source>
        <translation>&amp;Restaurar</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="776"/>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimizar</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="782"/>
        <source>Roll down</source>
        <translation>Desenrollar</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="788"/>
        <source>Roll up</source>
        <translation>Enrollar</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="796"/>
        <source>&amp;Layer</source>
        <translation>&amp;Capa</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="798"/>
        <source>Always on &amp;top</source>
        <translation>Siempre &amp;encima</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="804"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="810"/>
        <source>Always on &amp;bottom</source>
        <translation>Siempre al &amp;fondo</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="818"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="81"/>
        <source>Group</source>
        <translation>Grupo</translation>
    </message>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="83"/>
        <source>Close group</source>
        <translation>Cerrar el grupo</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Configuración del Administrador de tareas</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Mostrar solo ventanas del escritorio</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Mostrar solo ventanas de la pantalla del &amp;panel</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Mostrar solo ventanas minimizadas</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Elevar ventanas minimizadas del escritorio actual</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Rotar las ventanas con la rueda del ratón</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="143"/>
        <source>Window &amp;grouping</source>
        <translation>A&amp;grupación de ventanas</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="152"/>
        <source>Show popup on mouse hover</source>
        <translation>Mostrar mensaje de ayuda al mover el ratón encima</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="169"/>
        <source>Appearance</source>
        <translation>Apariencia</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="188"/>
        <source>Maximum button width</source>
        <translation>Ancho máximo del botón</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="125"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="201"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="227"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="86"/>
        <source>Mouse Wheel</source>
        <translation>Rueda del ratón</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Wheel Delta Threshold</source>
        <translation>Umbral de variación de la rueda</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
        <source>Put buttons of the same class next to each other</source>
        <translation>Poner juntos los botones de la misma clase</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="214"/>
        <source>Maximum button height</source>
        <translation>Alto máximo del botón</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="247"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Usar iconos de WindowClass, si están disponibles</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="240"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>&amp;Rotar automáticamente los botones cuando el panel esté vertical</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="178"/>
        <source>Button style</source>
        <translation>Estilo del botón</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Cerrar con el botón central</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="44"/>
        <source>Icon and text</source>
        <translation>Icono y texto</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Only icon</source>
        <translation>Solo icono</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only text</source>
        <translation>Solo texto</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
        <source>Disabled</source>
        <translation>Deshabilitado</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="50"/>
        <source>Scroll up to raise, down to minimize</source>
        <translation>Desplazar hacia arriba para elevar, hacia abajo para minimizar</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="51"/>
        <source>Scroll up to minimize, down to raise</source>
        <translation>Desplazar hacia arriba para minimizar, hacia abajo para elevar</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="52"/>
        <source>Scroll up to move to next desktop, down to previous</source>
        <translation>Desplazar hacia arriba para ir al siguiente escritorio, hacia abajo para ir al anterior</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="53"/>
        <source>Scroll up to move to previous desktop, down to next</source>
        <translation>Desplazar hacia arriba para ir al escritorio anterior, hacia abajo para ir al siguiente</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="55"/>
        <source>Current</source>
        <translation>Actual</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.1.1.tar.xz: lxqt-panel-2.1.1/plugin-taskbar/translations/taskbar_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../lxqttaskbar.cpp" line="636"/>
        <source>Activate task %1</source>
        <translation>Activar la tarea %1</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="546"/>
        <source>Application</source>
        <translation>Aplicación</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="580"/>
        <source>To &amp;Desktop</source>
        <translation>Al &amp;escritorio</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="583"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Todos los escritorios</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="593"/>
        <source>Desktop &amp;%1</source>
        <translation>Escritorio &amp;%1</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="603"/>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Al escritorio actual</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="612"/>
        <source>Move To N&amp;ext Monitor</source>
        <translation>Al monitor &amp;siguiente</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="618"/>
        <source>Move To &amp;Previous Monitor</source>
        <translation>Al m&amp;onitor anterior</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="624"/>
        <source>&amp;Move</source>
        <translation>&amp;Mover</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="629"/>
        <source>Resi&amp;ze</source>
        <translation>Re&amp;dimensionar</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="638"/>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximizar</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="647"/>
        <source>Maximize vertically</source>
        <translation>Maximizar verticalmente</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="654"/>
        <source>Maximize horizontally</source>
        <translation>Maximizar horizontalmente</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="662"/>
        <source>&amp;Restore</source>
        <translation>&amp;Restaurar</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="670"/>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimizar</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="678"/>
        <source>Roll down</source>
        <translation>Desenrollar</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="686"/>
        <source>Roll up</source>
        <translation>Enrollar</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="695"/>
        <source>&amp;Layer</source>
        <translation>Ca&amp;pa</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="700"/>
        <source>Always on &amp;top</source>
        <translation>Siempre &amp;encima</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="705"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="710"/>
        <source>Always on &amp;bottom</source>
        <translation>Siempre al &amp;fondo</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="717"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="84"/>
        <source>Group</source>
        <translation>Grupo</translation>
    </message>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="86"/>
        <source>Close group</source>
        <translation>Cerrar el grupo</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Configuración del Administrador de tareas</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Mostrar solo ventanas del escritorio</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Mostrar solo ventanas de la pantalla del &amp;panel</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Mostrar solo ventanas minimizadas</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Elevar ventanas minimizadas del escritorio actual</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="51"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Rotar las ventanas con la rueda del ratón</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="143"/>
        <source>Window &amp;grouping</source>
        <translation>A&amp;grupación de ventanas</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="152"/>
        <source>Show popup on mouse hover</source>
        <translation>Mostrar mensaje de ayuda al mover el ratón encima</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="169"/>
        <source>Appearance</source>
        <translation>Apariencia</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="188"/>
        <source>Maximum button width</source>
        <translation>Ancho máximo del botón</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="125"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="201"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="227"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="86"/>
        <source>Mouse Wheel</source>
        <translation>Rueda del ratón</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Wheel Delta Threshold</source>
        <translation>Umbral de variación de la rueda</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
        <source>Put buttons of the same class next to each other</source>
        <translation>Poner juntos los botones de la misma clase</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="214"/>
        <source>Maximum button height</source>
        <translation>Alto máximo del botón</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="247"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Usar iconos de WindowClass, si están disponibles</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="240"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>&amp;Rotar automáticamente los botones cuando el panel esté vertical</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="178"/>
        <source>Button style</source>
        <translation>Estilo del botón</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Cerrar con el botón central</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Icon and text</source>
        <translation>Icono y texto</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="47"/>
        <source>Only icon</source>
        <translation>Solo icono</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
        <source>Only text</source>
        <translation>Solo texto</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="50"/>
        <source>Disabled</source>
        <translation>Deshabilitado</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="52"/>
        <source>Scroll up to raise, down to minimize</source>
        <translation>Desplazar hacia arriba para elevar, hacia abajo para minimizar</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="53"/>
        <source>Scroll up to minimize, down to raise</source>
        <translation>Desplazar hacia arriba para minimizar, hacia abajo para elevar</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="54"/>
        <source>Scroll up to move to next desktop, down to previous</source>
        <translation>Desplazar hacia arriba para ir al siguiente escritorio, hacia abajo para ir al anterior</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="55"/>
        <source>Scroll up to move to previous desktop, down to next</source>
        <translation>Desplazar hacia arriba para ir al escritorio anterior, hacia abajo para ir al siguiente</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="60"/>
        <source>Current</source>
        <translation>Actual</translation>
    </message>
</context>
</TS>
